16.165. cdist-type__xymon_apache(7) — cdist 6.9.8 documentation

# 16.165. cdist-type__xymon_apache(7)

## 16.165.1. NAME

cdist-type__xymon_apache - Configure apache2-webserver for Xymon

## 16.165.2. DESCRIPTION

This cdist type installs and configures apache2 to be used "exclusively" (in the sense that no other use is taken care of) with Xymon (the systems and network monitor).

It depends on __xymon_server.

## 16.165.3. REQUIRED PARAMETERS

None.

## 16.165.4. OPTIONAL PARAMETERS

state

  'present', 'absent', defaults to 'present'.

ipacl

  IP(-ranges) that have access to the Xymon webpages and CGIs. Apache2-style syntax suitable for Require ip .... Example: 192.168.1.0/24 10.0.0.0/8

## 16.165.5. MESSAGES

mod:rewrite enabled

  apache module enabled

conf:xymon enabled

  apache config for xymon enabled

apache restarted

  apache2.service was reloaded

apache reloaded

  apache2.service was restarted

## 16.165.6. EXPLORERS

active-conf

  lists apache2 conf-enabled

active-modules

  lists active apache2-modules

## 16.165.7. EXAMPLES

    # minmal, only localhost-access:
    __xymon_apache
    # allow more IPs to access the Xymon-webinterface:
    __xymon_apache --ipacl "192.168.0.0/16 10.0.0.0/8" --state "present"

## 16.165.8. SEE ALSO

cdist__xymon_server(7)

## 16.165.9. AUTHORS

Thomas Eckert <tom--@--it-eckert.de>

## 16.165.10. COPYING

Copyright (C) 2018-2019 Thomas Eckert. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.